@@ -165,7 +165,7 @@
  *    to create a clean (empty) enviroment for the test user "syncmltest".  See
  *    the Horde_SyncMl_Backend_Sql implementation for details.
  *
- * Copyright 2005-2012 Horde LLC (http://www.horde.org/)
+ * Copyright 2005-2013 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -662,7 +662,7 @@ class Horde_SyncMl_Backend
      *
      * @return string  The user name.
      */
-    public function setAuthenticated($username, $credData)
+    protected function _setAuthenticated($username, $credData)
     {
         die('setAuthenticated() not implemented!');
     }
